@@ -63,11 +63,12 @@ import ch.qos.logback.core.pattern.parser.Parser;
 public class PatternLayout extends PatternLayoutBase<IAccessEvent> {
 
   public static final Map<String, String> defaultConverterMap = new HashMap<String, String>();
+  public static final String HEADER_PREFIX = "#logback.access pattern: ";
 
-  public static String CLF_PATTERN = "%h %l %u %t \"%r\" %s %b";
+  public static String CLF_PATTERN = "%h %l %u [%t] \"%r\" %s %b";
   public static String CLF_PATTERN_NAME = "common";
   public static String CLF_PATTERN_NAME_2 = "clf";
-  public static String COMBINED_PATTERN = "%h %l %u %t \"%r\" %s %b \"%i{Referer}\" \"%i{User-Agent}\"";
+  public static String COMBINED_PATTERN = "%h %l %u [%t] \"%r\" %s %b \"%i{Referer}\" \"%i{User-Agent}\"";
   public static String COMBINED_PATTERN_NAME = "combined";
 
   static {
@@ -184,4 +185,10 @@ public class PatternLayout extends PatternLayoutBase<IAccessEvent> {
     }
     super.start();
   }
+
+
+  @Override
+  protected String getPresentationHeaderPrefix() {
+    return HEADER_PREFIX;
+  }
 }
