@@ -33,21 +33,19 @@ import ch.qos.logback.core.testUtil.RandomUtil;
 public class JettyBasicTest {
 
   static RequestLogImpl REQYEST_LOG_IMPL;
-  static JettyFixture JETTY_FIXTURE;
+  static JettyFixtureWithListAndConsoleAppenders JETTY_FIXTURE;
 
   static int RANDOM_SERVER_PORT = RandomUtil.getRandomServerPort();
   
   @BeforeClass
   static public void startServer() throws Exception {
-    // System.out.println("*** JettyBasicTest.startServer called");
     REQYEST_LOG_IMPL = new RequestLogImpl();
-    JETTY_FIXTURE = new JettyFixture(REQYEST_LOG_IMPL, RANDOM_SERVER_PORT);
+    JETTY_FIXTURE = new JettyFixtureWithListAndConsoleAppenders(REQYEST_LOG_IMPL, RANDOM_SERVER_PORT);
     JETTY_FIXTURE.start();
   }
 
   @AfterClass
   static public void stopServer() throws Exception {
-    // System.out.println("*** JettyBasicTest.stopServer called");
     if (JETTY_FIXTURE != null) {
       JETTY_FIXTURE.stop();
     }
