@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -16,14 +16,14 @@ package ch.qos.logback.access.testUtil;
 import java.util.ArrayList;
 import java.util.List;
 
-import ch.qos.logback.access.spi.AccessEvent;
+import ch.qos.logback.access.spi.IAccessEvent;
 import ch.qos.logback.core.AppenderBase;
 
-public class NotifyingListAppender extends AppenderBase<AccessEvent> {
+public class NotifyingListAppender extends AppenderBase<IAccessEvent> {
 
-  public List<AccessEvent> list = new ArrayList<AccessEvent>();
+  public List<IAccessEvent> list = new ArrayList<IAccessEvent>();
   
-  protected void append(AccessEvent e) {
+  protected void append(IAccessEvent e) {
     list.add(e);
     synchronized (this) {
       this.notify();
