@@ -18,12 +18,11 @@ import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
-@SuiteClasses( { LoggerContextTest.class, LoggerPerfTest.class,
-    ScenarioBasedLoggerContextTest.class, PatternLayoutTest.class,
-    LoggerTest.class, LoggerSerializationTest.class,
-    MessageFormattingTest.class, MDCTest.class,
-    TurboFilteringInLoggerTest.class })
-
-    
+@SuiteClasses({LoggerContextTest.class, LoggerPerfTest.class,
+        ScenarioBasedLoggerContextTest.class, PatternLayoutTest.class,
+        LoggerTest.class, LoggerSerializationTest.class,
+        MessageFormattingTest.class, MDCTest.class,
+        TurboFilteringInLoggerTest.class,
+        AsyncAppenderTest.class})
 public class PackageTest {
 }
\ No newline at end of file
