@@ -59,10 +59,9 @@ public class JaninoEventEvaluatorTest {
   }
 
   LoggingEvent makeLoggingEvent(Exception ex) {
-    LoggingEvent e = new LoggingEvent(
+    return new LoggingEvent(
         ch.qos.logback.core.pattern.FormattingConverter.class.getName(),
         logger, Level.INFO, "Some message", ex, null);
-    return e;
   }
 
   @Test
