@@ -13,12 +13,12 @@
  */
 package ch.qos.logback.classic.net.testObjectBuilders;
 
-public interface Builder {
+public interface Builder<E> {
 
   // 45 characters message
-  final String MSG_PREFIX = "aaaaabbbbbcccccdddddaaaaabbbbbcccccdddddaaaa";
+  String MSG_PREFIX = "aaaaabbbbbcccccdddddaaaaabbbbbcccccdddddaaaa";
 
   // final String MSG_PREFIX = "a";
 
-  Object build(int i);
+  E build(int i);
 }
