@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -18,10 +18,11 @@ import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
-@SuiteClasses( { ConverterTest.class,
-    TargetLengthBasedClassNameAbbreviatorTest.class, MDCConverterTest.class,
-    MarkerConverterTest.class, ExtendedThrowableProxyConverterTest.class,
-    ThrowableProxyConverterTest.class })
+@SuiteClasses({ConverterTest.class,
+        TargetLengthBasedClassNameAbbreviatorTest.class, MDCConverterTest.class,
+        MarkerConverterTest.class, ExtendedThrowableProxyConverterTest.class,
+        ThrowableProxyConverterTest.class,
+        RootCauseFirstThrowableProxyConverterTest.class})
 public class PackageTest {
 
 }
\ No newline at end of file
