@@ -47,10 +47,9 @@ public class ThrowableProxyConverterTest {
   }
 
   private ILoggingEvent createLoggingEvent(Throwable t) {
-    ILoggingEvent le = new LoggingEvent(this.getClass().getName(), lc
+    return new LoggingEvent(this.getClass().getName(), lc
         .getLogger(Logger.ROOT_LOGGER_NAME), Level.DEBUG, "test message", t,
         null);
-    return le;
   }
 
   @Test
