@@ -25,19 +25,21 @@ import ch.qos.logback.classic.selector.servlet.ContextDetachingSCL;
 import ch.qos.logback.classic.util.ContextSelectorStaticBinder;
 import ch.qos.logback.classic.util.MockInitialContext;
 import ch.qos.logback.classic.util.MockInitialContextFactory;
+import org.slf4j.LoggerFactoryFriend;
+import org.slf4j.impl.StaticLoggerBinderFriend;
 
 public class ContextDetachingSCLTest  {
   
   static String INITIAL_CONTEXT_KEY = "java.naming.factory.initial";
 
-  ContextDetachingSCL cobtextDetachingSCL;
+  ContextDetachingSCL contextDetachingSCL;
   
   @Before
   public void setUp() throws Exception {
+
     System.setProperty(ClassicConstants.LOGBACK_CONTEXT_SELECTOR, "JNDI");
-    //LoggerFactory.setup();
-    
-    cobtextDetachingSCL = new ContextDetachingSCL();
+
+    contextDetachingSCL = new ContextDetachingSCL();
     
     MockInitialContextFactory.initialize();
     MockInitialContext mic = MockInitialContextFactory.getContext();
@@ -45,21 +47,27 @@ public class ContextDetachingSCLTest  {
     
     //The property must be set after we setup the Mock
     System.setProperty(INITIAL_CONTEXT_KEY, MockInitialContextFactory.class.getName());
-    
+
+    // reinitialize the LoggerFactory, These reset methods are reserved for internal use
+    StaticLoggerBinderFriend.reset();
+    LoggerFactoryFriend.reset();
+
     //this call will create the context "toto"
     LoggerFactory.getLogger(ContextDetachingSCLTest.class);
-
   }
 
   @After
   public void tearDown() throws Exception {
     System.clearProperty(INITIAL_CONTEXT_KEY);
+    // reinitialize the LoggerFactory, These resets method are reserved for internal use
+    StaticLoggerBinderFriend.reset();
+    LoggerFactoryFriend.reset();
   }
 
   @Test
   public void testDetach() {
     ContextJNDISelector selector = (ContextJNDISelector) ContextSelectorStaticBinder.getSingleton().getContextSelector();
-    cobtextDetachingSCL.contextDestroyed(null);
+    contextDetachingSCL.contextDestroyed(null);
     assertEquals(0, selector.getCount());
   }
   
@@ -73,7 +81,7 @@ public class ContextDetachingSCLTest  {
 
     mic.map.put(ClassicConstants.JNDI_CONTEXT_NAME, "titi");
     assertEquals("titi", selector.getLoggerContext().getName());
-    cobtextDetachingSCL.contextDestroyed(null);
+    contextDetachingSCL.contextDestroyed(null);
 
     assertEquals(2, selector.getCount());
   }
