@@ -1,3 +1,16 @@
+/**
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
+ */
 package ch.qos.logback.classic.spi;
 
 import static org.junit.Assert.assertEquals;
@@ -14,7 +27,7 @@ public class CallerDataTest  {
     Throwable t = new Throwable();
     StackTraceElement[] steArray = t.getStackTrace();
     
-    CallerData[] cda = CallerData.extract(t, CallerDataTest.class.getName());
+    StackTraceElement[] cda = CallerData.extract(t, CallerDataTest.class.getName(), 50);
     assertNotNull(cda);
     assertTrue(cda.length > 0);
     assertEquals(steArray.length - 1, cda.length);
@@ -27,7 +40,7 @@ public class CallerDataTest  {
    */
   @Test
   public void testDeferredProcessing() {
-    CallerData[] cda = CallerData.extract(new Throwable(), "com.inexistent.foo");
+    StackTraceElement[] cda = CallerData.extract(new Throwable(), "com.inexistent.foo", 10);
     assertNotNull(cda);
     assertEquals(0, cda.length);
   }
