@@ -1,6 +1,6 @@
 /**
  * Logback: the reliable, generic, fast and flexible logging framework.
- * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ * Copyright (C) 1999-2011, QOS.ch. All rights reserved.
  *
  * This program and the accompanying materials are dual-licensed under
  * either the terms of the Eclipse Public License v1.0 as published by
@@ -35,42 +35,44 @@ public class CoreConstants {
 
   public static final String ISO8601_STR = "ISO8601";
   public static final String ISO8601_PATTERN = "yyyy-MM-dd HH:mm:ss,SSS";
+  public static final String DAILY_DATE_PATTERN = "yyyy-MM-dd";
 
   /**
    * Time format used in Common Log Format
    */
-  static public final String CLF_DATE_PATTERN = "dd/MM/yyyy:HH:mm:ss Z";
+  public static final String CLF_DATE_PATTERN = "dd/MM/yyyy:HH:mm:ss Z";
 
   /**
    * The key used in locating the evaluator map in context's object map.
    */
-  static public final String EVALUATOR_MAP = "EVALUATOR_MAP";
+  public static final String EVALUATOR_MAP = "EVALUATOR_MAP";
 
   /**
    * By convention, we assume that the static method named "valueOf" taking
    * a string argument can restore a given object from its string
    * representation.
    */
-  static public final String VALUE_OF = "valueOf";
+  public static final String VALUE_OF = "valueOf";
 
   /**
    * An empty string.
    */
-  public final static String EMPTY_STRING = "";
+  public static final String EMPTY_STRING = "";
 
   /**
    * An empty string array.
    */
-  public final static String[] EMPTY_STRING_ARRAY = new String[] {};
+  public static final String[] EMPTY_STRING_ARRAY = new String[]{};
 
   /**
    * An empty Class array.
    */
-  public final static Class<?>[] EMPTY_CLASS_ARRAY = new Class[] {};
-  public final static String CAUSED_BY = "Caused by: ";
+  public static final Class<?>[] EMPTY_CLASS_ARRAY = new Class[]{};
+  public static final String CAUSED_BY = "Caused by: ";
+  public static final String SUPPRESSED = "\tSuppressed: ";
+  public static final String WRAPPED_BY = "Wrapped by: ";
 
-
-  public final static char PERCENT_CHAR = '%';
+  public static final char PERCENT_CHAR = '%';
   public static final char LEFT_PARENTHESIS_CHAR = '(';
   public static final char RIGHT_PARENTHESIS_CHAR = ')';
 
@@ -81,7 +83,6 @@ public class CoreConstants {
   public static final char DOUBLE_QUOTE_CHAR = '"';
   public static final char SINGLE_QUOTE_CHAR = '\'';
 
-
   /**
    * Number of rows before in an HTML table before,
    * we close the table and create a new one
@@ -101,16 +102,21 @@ public class CoreConstants {
 
 
   // the max number of times an error should be reported
-  static public final int MAX_ERROR_COUNT = 4;
+  public static final int MAX_ERROR_COUNT = 4;
 
 
-  static public final char DOT = '.';
-  static public final char TAB = '\t';
-  static public final char DOLLAR = '$';
+  public static final char DOT = '.';
+  public static final char TAB = '\t';
+  public static final char DOLLAR = '$';
 
-  static public final String SEE_FNP_NOT_SET = "See also http://logback.qos.ch/codes.html#tbr_fnp_not_set";
+  public static final String SEE_FNP_NOT_SET = "See also http://logback.qos.ch/codes.html#tbr_fnp_not_set";
+
+  public static final String CONFIGURATION_WATCH_LIST = "CONFIGURATION_WATCH_LIST";
+  public static final String CONFIGURATION_WATCH_LIST_RESET = "CONFIGURATION_WATCH_LIST_RESET";
+
+  public static final String SAFE_JORAN_CONFIGURATION = "SAFE_JORAN_CONFIGURATION";
+  public static final String XML_PARSING = "XML_PARSING";
 
-  public static String CONFIGURATION_WATCH_LIST = "CONFIGURATION_WATCH_LIST";
 
 
   /**
@@ -121,11 +127,19 @@ public class CoreConstants {
 
   /**
    * The key under which the current context name is registered in the logger
-   * context. 
+   * context.
    */
   public static final String CONTEXT_NAME_KEY = "CONTEXT_NAME";
 
 
   public static int BYTES_PER_INT = 4;
   public static final int MILLIS_IN_ONE_SECOND = 1000;
+  public static final int MILLIS_IN_ONE_MINUTE = MILLIS_IN_ONE_SECOND*60;
+  public static final int MILLIS_IN_ONE_HOUR = MILLIS_IN_ONE_MINUTE*60;
+  public static final int MILLIS_IN_ONE_DAY = MILLIS_IN_ONE_HOUR*24;
+  public static final int MILLIS_IN_ONE_WEEK = MILLIS_IN_ONE_DAY*7;
+
+  public static final String CONTEXT_SCOPE_VALUE = "context";
+
+  public static final String RESET_MSG_PREFIX = "Will reset and reconfigure context ";
 }
