@@ -14,13 +14,11 @@
 package ch.qos.logback.core.joran.conditional;
 
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Stack;
 
+import ch.qos.logback.core.joran.action.PropertyAction;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
@@ -38,14 +36,21 @@ import ch.qos.logback.core.testUtil.RandomUtil;
 import ch.qos.logback.core.util.CoreTestConstants;
 import ch.qos.logback.core.util.StatusPrinter;
 
+import static org.junit.Assert.*;
+
 public class IfThenElseTest {
 
   Context context = new ContextBase();
+  StatusChecker checker = new StatusChecker(context);
   TrivialConfigurator tc;
   int diff = RandomUtil.getPositiveInt();
   static final String CONDITIONAL_DIR_PREFIX = CoreTestConstants.JORAN_INPUT_PREFIX
   + "conditional/";
 
+  String ki1 = "ki1";
+  String val1 = "val1";
+  String sysKey = "sysKey";
+  String dynaKey = "dynaKey";
 
   StackAction stackAction = new StackAction();
 
@@ -54,12 +59,13 @@ public class IfThenElseTest {
     HashMap<Pattern, Action> rulesMap = new HashMap<Pattern, Action>();
     rulesMap.put(new Pattern("x"), new NOPAction());
     rulesMap.put(new Pattern("x/stack"), stackAction);
+    rulesMap.put(new Pattern("x/property"), new PropertyAction());
     rulesMap.put(new Pattern("*/if"), new IfAction());
     rulesMap.put(new Pattern("*/if/then"), new ThenAction());
     rulesMap.put(new Pattern("*/if/then/*"), new NOPAction());
     rulesMap.put(new Pattern("*/if/else"), new ElseAction());
-    rulesMap.put(new Pattern("*/if/else/*"), new NOPAction());    
-    
+    rulesMap.put(new Pattern("*/if/else/*"), new NOPAction());
+
     tc = new TrivialConfigurator(rulesMap);
     tc.setContext(context);
   }
@@ -67,51 +73,73 @@ public class IfThenElseTest {
   @After
   public void tearDown() throws Exception {
     StatusPrinter.printIfErrorsOccured(context);
-    //StackAction.reset();
+    System.clearProperty(sysKey);
   }
 
   @Test
-  public void if0_Then() throws JoranException {
-    context.putProperty("Ki1", "Val1");
+  public void whenContextPropertyIsSet_IfThenBranchIsEvaluated() throws JoranException {
+    context.putProperty(ki1, val1);
     tc.doConfigure(CONDITIONAL_DIR_PREFIX+"if0.xml");
     verifyConfig(new String[] {"BEGIN", "a", "END"});
   }
 
   @Test
-  public void if0_Else() throws JoranException {
+  public void whenLocalPropertyIsSet_IfThenBranchIsEvaluated() throws JoranException {
+    tc.doConfigure(CONDITIONAL_DIR_PREFIX+"if_localProperty.xml");
+    verifyConfig(new String[] {"BEGIN", "a", "END"});
+  }
+
+
+  @Test
+  public void whenNoPropertyIsDefined_ElseBranchIsEvaluated() throws JoranException {
     tc.doConfigure(CONDITIONAL_DIR_PREFIX+"if0.xml");
     verifyConfig(new String[] {"BEGIN", "b", "END"});
   }
 
   @Test
-  public void ifWithoutElse_True() throws JoranException {
-    context.putProperty("Ki1", "Val1");
+  public void whenContextPropertyIsSet_IfThenBranchIsEvaluated_NO_ELSE_DEFINED() throws JoranException {
+    context.putProperty(ki1, val1);
     tc.doConfigure(CONDITIONAL_DIR_PREFIX+"ifWithoutElse.xml");
     verifyConfig(new String[] {"BEGIN", "a", "END"});
   }
 
   @Test
-  public void ifWithoutElse_False() throws JoranException {
+  public void whenNoPropertyIsDefined_IfThenBranchIsNotEvaluated_NO_ELSE_DEFINED() throws JoranException {
     tc.doConfigure(CONDITIONAL_DIR_PREFIX+"ifWithoutElse.xml");
     verifyConfig(new String[] {"BEGIN", "END"});
-    StatusChecker checker = new StatusChecker(context);
     assertTrue(checker.isErrorFree(0));
   }
 
-  
   @Test
   public void nestedIf() throws JoranException {
     tc.doConfigure(CONDITIONAL_DIR_PREFIX+"nestedIf.xml");
-    StatusPrinter.printIfErrorsOccured(context);
     verifyConfig(new String[] {"BEGIN", "a", "c", "END"});
+    assertTrue(checker.isErrorFree(0));
   }
-  
-  void verifyConfig(String[] expected) {
+
+  @Test
+  public void useNonExistenceOfSystemPropertyToDefineAContextProperty() throws JoranException {
+    assertNull(System.getProperty(sysKey));
+    assertNull(context.getProperty(dynaKey));
+    tc.doConfigure(CONDITIONAL_DIR_PREFIX+"ifSystem.xml");
+    System.out.println(dynaKey+"="+context.getProperty(dynaKey));
+    assertNotNull(context.getProperty(dynaKey));
+  }
+
+  @Test
+  public void noContextPropertyShouldBeDefinedIfSystemPropertyExists() throws JoranException {
+    System.setProperty(sysKey, "a");
+    assertNull(context.getProperty(dynaKey));
+    System.out.println("before "+dynaKey+"="+context.getProperty(dynaKey));
+    tc.doConfigure(CONDITIONAL_DIR_PREFIX+"ifSystem.xml");
+    System.out.println(dynaKey+"="+context.getProperty(dynaKey));
+    assertNull(context.getProperty(dynaKey));
+  }
+
+  private void verifyConfig(String[] expected) {
     Stack<String> witness = new Stack<String>();
     witness.addAll(Arrays.asList(expected));
     assertEquals(witness, stackAction.getStack());
   }
-  
-  
-  
+
 }
