@@ -17,6 +17,7 @@ import static org.junit.Assert.assertEquals;
 
 import java.util.Calendar;
 
+import ch.qos.logback.core.util.StatusPrinter;
 import org.junit.Test;
 
 import ch.qos.logback.core.Context;
@@ -114,13 +115,13 @@ public class FileNamePatternTest {
       FileNamePattern fnp = new FileNamePattern("foo-%d{yyyy.MM.dd}-%i.txt",
           context);
       String regex = fnp.toRegex(cal.getTime());
-      assertEquals("foo-2003.05.20-(\\d{1,2}).txt", regex);
+      assertEquals("foo-2003.05.20-(\\d{1,3}).txt", regex);
     }
     {
       FileNamePattern fnp = new FileNamePattern("\\toto\\foo-%d{yyyy\\MM\\dd}-%i.txt",
           context);
       String regex = fnp.toRegex(cal.getTime());
-      assertEquals("/toto/foo-2003/05/20-(\\d{1,2}).txt", regex);
+      assertEquals("/toto/foo-2003/05/20-(\\d{1,3}).txt", regex);
     }
   }
 
@@ -139,4 +140,12 @@ public class FileNamePatternTest {
       assertEquals("foo-\\d{4}\\.\\d{2}\\.\\d{2}T-\\d{1,2}.txt", regex);
     }
   }
+
+  @Test
+  public void convertMultipleDates() {
+    Calendar cal = Calendar.getInstance();
+    cal.set(2003, 4, 20, 17, 55);
+    FileNamePattern fnp = new FileNamePattern("foo-%d{yyyy.MM, aux}/%d{yyyy.MM.dd}.txt", context);
+    assertEquals("foo-2003.05/2003.05.20.txt", fnp.convert(cal.getTime()));
+  }
 }
