@@ -16,8 +16,6 @@ package ch.qos.logback.core.spi;
 import org.junit.Test;
 
 import static junit.framework.Assert.assertEquals;
-import static junit.framework.Assert.assertNull;
-import static junit.framework.Assert.assertNotNull;
 
 /**
  * @author Ceki G&uuml;c&uuml;
