@@ -18,7 +18,9 @@ public class CoreTestConstants {
   public static final String TEST_DIR_PREFIX = "src/test/";
   public static final String JORAN_INPUT_PREFIX = TEST_DIR_PREFIX
       + "input/joran/";
-  public static final String OUTPUT_DIR_PREFIX = "target/test-output/";
+
+  public static final String TARGET_DIR = "target/";
+  public static final String OUTPUT_DIR_PREFIX = TARGET_DIR+"test-output/";
 
   public static final int SUCCESSFUL_EXIT_CODE = 8;
   public static final int FAILURE_EXIT_CODE = 1;
